#!/bin/bash

# author:	Marcel Petrick (mail@marcelpetrick.it)
#
# about:	script to rescale and combine and negative-convert all HDR-TIFF-files in one directory
#			into a fixed-layout-overview which resembles an old "contact sheet"
#
# license:	GNU General Public License v3.0 (see attached gpl-3.0.txt)
# version:	0.2 (added "just extract the first layer"; minor code-structure-improvements)
# date:		20150603
#
# history:
#			0.1 (initial release; basic workflow implemented)

echo "############################ start of the script ############################"

SKRIPTDIR=$( cd "$( dirname "${BASH_SOURCE[0]}" )" && pwd )

############################################################
############## create thumbnails first - currently with fixed size of 400px for the longer side
printf "\nCreate all thumbnails first - currently with fixed size of 400px for the longer side\n"

ALLFILES=`ls *.tif` #get all files inside the current folder which fit by suffix
#echo "$ALLFILES"

WORKINGDIR="0workingDir" #pre-fixed with 0 to make it appear on top of the file-view
mkdir $WORKINGDIR

for FILE in $ALLFILES
do
	echo "will work now on: $FILE" #print current file name
	
	#create all thumbnails: todo if possible then work just on the first layer
	convert -resize "400x400>" $FILE"[0]" $WORKINGDIR"/"$FILE".png" #works just on the first layer
done

############################################################
############### Append first rows all rows
ROWSIZE=6 #number of pictures per row! #is a constant ... open for discussion
printf "\nAppend first the thumbnails to rows with size $ROWSIZE \n"

ALLFILES=`ls $WORKINGDIR/*.png` #make it png
#echo "$ALLFILES"

APPENDDIR="1appendendStripsDir" #pre-fixed with 1 to make it appear on top of the file-view
mkdir $APPENDDIR

TOADD="" #contain the working set of files for appending
APPENDEDSTRIPS="" #contain the intermediate strips
COUNTER=0
FILECOUNTER=0
LASTFILE=""

for FILE in $ALLFILES
do
#	echo "COUNTER == $COUNTER"
	LASTFILE=$FILE

	if (($COUNTER == $ROWSIZE)); then
#		echo "combine now! content: $TOADD"		
  		convert $TOADD +append $APPENDDIR/"combined"$FILECOUNTER".png" #combine it into one long column
		((FILECOUNTER+=1))
		COUNTER=0
		TOADD=""
#		echo "toadd now: $TOADD"
	fi

	#the regular append of the filename
	TOADD=$TOADD" $FILE"
	((COUNTER+=1))
done

############################################################
############### if TOADD not empty, then add another strip ... and fill it up with newly created frames
printf "\nCheck now if it is necessary to fill the last row to fit to the size of the other rows\n"

if [ -n "$TOADD" ]; then
    echo "TOADD not empty .. so fill up the last strip with the very last thumbnail (repeat $LASTFILE)"
#    echo "COUNTER has value $COUNTER" #add now (6 - counter -1) strips / means: repeat the last one
    
    #add the last thumbnail until filled up
	until [ $COUNTER == $ROWSIZE ]; do
#		echo "counter: $COUNTER"
		TOADD=$TOADD" $LASTFILE"
		((COUNTER+=1))
	done
	
	#combine then
#    echo "combine now! content: $TOADD"
    convert $TOADD +append $APPENDDIR/"combined"$FILECOUNTER".png"
else
    echo "TOADD empty .. change nothing"
fi

############################################################
############### combine now the strips to the whole thing
printf "\nCombine now the horizontal strips into the complete contact sheet\n"

ALLFILES=`ls $APPENDDIR/*.png` #make it png
TOADD=""

echo "$ALLFILES"

for FILE in $ALLFILES
do
	TOADD=$TOADD" $FILE"
done

#make the final apppend of all rows
printf "\nDo now the final combine into a single sheet..\n"
convert $TOADD -append combinedSheet.png

############################################################
############### do the final steps now like conversion and histogram changes
printf "\nDo the final processing now ..\n"

#run negfix8 on it ...
printf "\nDo negfix8 now ..\n"
#echo "source: $SKRIPTDIR" #use the current skript dir - because createContactsheet.sh and negfix8.sh should be in the same directory
/bin/bash $SKRIPTDIR/negfix8.sh combinedSheet.png combinedSheet_negfix8.png
#/bin/bash ../negfix8.sh -cs combinedSheet.png combinedSheet_negfix8cs.png # already built-in contrast spread

#spread the histogram
printf "\nSpread the histogram\n"
#convert -contrast-stretch 0.25% combinedSheet_negfix8.png combinedSheet_negfix8_stretched0.25.png
convert -contrast-stretch 0.5% combinedSheet_negfix8.png combinedSheet_negfix8_stretched0.50.png
convert -contrast-stretch 1% combinedSheet_negfix8.png combinedSheet_negfix8_stretched1.00.png
#convert -contrast-stretch 0.25% combinedSheet_negfix8cs.png combinedSheet_negfix8cs_stretched0.25.png
#convert -contrast-stretch 0.5% combinedSheet_negfix8cs.png combinedSheet_negfix8cs_stretched0.50.png
#convert -contrast-stretch 1% combinedSheet_negfix8cs.png combinedSheet_negfix8cs_stretched1.00.png

############################################################
############### clean the output - maybe add this as a switch to the call-params
printf "\nClean the output..\n"

rm -R $WORKINGDIR
rm -R $APPENDDIR
rm combinedSheet.png
rm combinedSheet_negfix8.png

printf "everything is finished: check for the two files named combinedSheet_negfix8_stretched0.50.png\nand combinedSheet_negfix8_stretched1.00.png.\nIf missing, check for errors ;)\n"
printf "############################ end of the script ############################\n"
